library(mlxR)


# 1 - resimulate final project for double absorption of veralipride with AUC


project.file <- "monolix_projects/project_7_double_first_order_oral.mlxtran"


# Add a formula for AUC and define AUC in the output

add <- list(formula=c("ddt_AUC = Cc"))
outCc <- list(name= c("Cc"), time=seq(0,25, by=0.5))
outAUC <- list(name= c("AUC"), time=25)


# Simulation

res1 <- simulx(project = project.file,
               addlines = add,
               output    = list(outCc, outAUC),
               group = list(size=500),
               settings = list(seed=12345))


# Plot concentration curves over time

pLines <- ggplot(res1$Cc)+
  geom_point(aes(x=time,y=Cc, color=id))+geom_line(aes(x=time,y=Cc, color=id))+
  scale_x_continuous("Time (min)") +scale_y_continuous("Concentration (ug/L)")+
  guides(colour=FALSE)
print(pLines)


# Plot concentration percentiles over time

prct <- prctilemlx(res1$Cc)
print(prct)


# Plot histogram of AUC values

histAUC <- ggplotmlx(res1$AUC, aes(AUC))+geom_histogram(bins=30, fill='#16a4ca', color="black")+
  xlab('AUC')+ylab('Number of individuals in each bin')
print(histAUC)


# Compute AUC quartiles

AUCq <- quantile(res1$AUC$AUC)
names(AUCq) <- paste0("Q",0:4)

# Create column AUCq with AUC quartile of each id
res1$AUC$AUCq <- sapply(res1$AUC$AUC, function(x){names(AUCq[x<AUCq])[1]})
res1$Cc$AUCq <- factor(res1$AUC$AUCq[res1$Cc$id], levels=names(AUCq))


# Plot concentration percentiles over time, grouped by AUC quartiles

prctq <- prctilemlx(res1$Cc, group="AUCq")+ theme(legend.position = "none")
print(prctq)



# 2 - Compute therapeutic window


# Add lines in the model to define the time spent above
# a target concentration Ctarget=200


add <- list(formula=c("Ctarget=200",
                      "TimeAboveTarget_0 = 0",
                      "if  Cc > Ctarget",
                      "xTime = 1",
                      "else",
                      "xTime = 0",
                      "end",
                      "ddt_TimeAboveTarget = xTime"))

out <- list(name= c("TimeAboveTarget"), time=100)

# Simulation

res2 <- simulx(project = project.file,
              addlines = add,
              output    = out,
              group = list(size=500),
              settings = list(seed=12345))


# Plot histogram of times

histTimeAboveTarget <- ggplotmlx(res2$TimeAboveTarget, aes(TimeAboveTarget))+geom_histogram(bins=20, fill='#16a4ca', color="black")+
  xlab('Time above target concentration')+ylab('Number of individuals in each bin')
print(histTimeAboveTarget)

percentTargetTime <- sum(res2$TimeAboveTarget$TimeAboveTarget>2)/nrow(res2$TimeAboveTarget)

print(paste0("Percentage of individuals for which the concentration stay above the target during at least 2h: ",percentTargetTime*100,"%"))


